@@ -1,3 +1,17 @@
+# pylint: disable=invalid-name
+"""
+Mie scattering in pure python
+
+`miepython` is a pure Python module to calculate light scattering by non-absorbing,
+partially-absorbing, or perfectly conducting spheres. Mie theory
+is used, following the procedure in given by Wiscombe in
+http://opensky.ucar.edu/islandora/object/technotes:232 and validated against his results.
+
+This code provides functions for calculating the extinction efficiency,
+scattering efficiency, backscattering, and scattering asymmetry. Moreover,
+a set of angles can be given to calculate the scattering for a sphere.
+"""
+
 from __future__ import division
 
 import numpy as np
@@ -72,10 +86,10 @@ def _D_calc(m, x, N):
     """
     n = m.real
     kappa = abs(m.imag)
-    
-    if n < 1 or n>10 or kappa > 10 or x*kappa >= 3.9 - 10.8 * n + 13.78 * n**2:
+
+    if n < 1 or n > 10 or kappa > 10 or x*kappa >= 3.9 - 10.8 * n + 13.78 * n**2:
         return _D_downwards(m*x, N)
-        
+
     return _D_upwards(m*x, N)
 
 
@@ -142,7 +156,7 @@ def _small_conducting_mie(m, x):
     g += ahat1.real * bhat1.real
     g *= 6 * x**4 / qsca
 
-    qback = 3 * np.pi * x**4 * abs(ahat1 - bhat1 - 5 / 3 * (ahat2 - bhat2))**2
+    qback = 9 * x**4 * abs(ahat1 - bhat1 - 5 / 3 * (ahat2 - bhat2))**2
 
     return [qext, qsca, qback, g]
 
@@ -154,68 +168,33 @@ def _small_mie(m, x):
         the scattering asymmetry for small spheres (x<0.1)
     """
     m2 = m * m
-    m4 = m2 * m2
     x2 = x * x
-    x3 = x2 * x
-    x4 = x2 * x2
 
-    D = m2 + 2 + (1 - 0.7 * m2) * x2 - (8 * m4 - 385 * m2 + 350) * x4 / 1400.0 + \
-        2j * (m2 - 1) * x3 * (1 - 0.1 * x2) / 3
-    ahat1 = 2j * (m2 - 1) / 3 * (1 - 0.1 * x2 + (4 * m2 + 5) * x4 / 1400) / D
+    D = m2 + 2 + (1 - 0.7 * m2) * x2 - (8 * m**4 - 385 * m2 + 350) * x**4 / 1400.0 + \
+        2j * (m2 - 1) * x**3 * (1 - 0.1 * x2) / 3
+    ahat1 = 2j * (m2 - 1) / 3 * (1 - 0.1 * x2 + (4 * m2 + 5) * x**4 / 1400) / D
     bhat1 = 1j * x2 * (m2 - 1) / 45 * (1 + (2 * m2 - 5) /
                                        70 * x2) / (1 - (2 * m2 - 5) / 30 * x2)
     ahat2 = 1j * x2 * (m2 - 1) / 15 * (1 - x2 / 14) / \
         (2 * m2 + 3 - (2 * m2 - 7) / 14 * x2)
 
-    qext = 6 * x * (ahat1 + bhat1 + 5 * ahat2 / 3).real
     T = abs(ahat1)**2 + abs(bhat1)**2 + 5 / 3 * abs(ahat2)**2
     temp = ahat2 + bhat1
     g = (ahat1 * temp.conjugate()).real / T
 
-    qsca = qext
-    if m.imag < 0:
-        qsca = 6 * x4 * T
+    qsca = 6 * x**4 * T
+
+    if m.imag == 0:
+        qext = qsca
+    else:
+        qext = 6 * x * (ahat1 + bhat1 + 5 * ahat2 / 3).real
+
+    sback = 1.5 * x**3 * (ahat1 - bhat1 - 5 * ahat2 / 3)
+    qback = 4*abs(sback)**2/x2
 
-    qback = 3 * np.pi * x4 * abs(ahat1 - bhat1 - 5 * ahat2 / 3)**2
     return [qext, qsca, qback, g]
 
 
-def _large_mie(m, x):
-    """ Compute the efficiencies for a large spheres with index m.
-
-        The total extinction, scattering, and backscattering as well as
-        the scattering asymmetry for large spheres (x>100)
-    """
-
-    kappa = -np.imag(m)
-    n = np.real(m)
-    rho = 2*x*np.abs(m-1)
-    beta = np.arctan2(kappa,n-1)
-    epsilon = 0.25 + 0.61*(1-np.exp(-8*np.pi/3*kappa))**2
-
-    Qext_adt = 2
-    Qext_adt += -4*ex*np.cos(beta)/rho*np.sin(rho-beta)
-    Qext_adt += -4*ex*np.cos(beta)**2/rho**2*np.cos(rho-2*beta)
-    Qext_adt += 4*np.cos(beta)**2/rho**2*np.cos(2*beta)
-
-    Qabs_adt = 1
-    Qabs_adt += 2*np.exp(-4*kappa*x)/(4*kappa*x)
-    Qabs_adt += 2*(np.exp(-4*kappa*x)-1)/(4*kappa*x)**2
-
-    c1 = 0.25*(1+np.exp(-1167*kappa))*(1-Qabs_adt)
-    c2 = np.sqrt(2*epsilon*x/np.pi)*np.exp(0.5-epsilon*x/np.pi)*(0.7393*n-0.6069)
-    Qabs_madt = (1+c1+c2)*Qabs_adt
-
-    Qedge = (1-np.exp(-0.06*x))*x**(-2/3)
-    Qext_madt = (1+0.5*c2)*Qext_adt+Qedge
-    
-    qback = ((n-1)**2 + kappa**2)/((n+1)**2+kappa**2)
-    
-    qext = Qext_madt
-    qsca = Qext_madt - Qabs_madt
-    return [qext, qsca, qback, g]
-    
-
 def _mie_scalar(m, x):
     """ Calculates [qext, qsca, qback, g] for a sphere with index m and size x.
 
@@ -238,15 +217,14 @@ def _mie_scalar(m, x):
     nmax = len(a)
     n = np.arange(1, nmax + 1)
     cn = 2.0 * n + 1.0
-    x2 = x * x
 
-    qext = 2 * np.sum(cn * (a.real + b.real)) / x2
+    qext = 2 * np.sum(cn * (a.real + b.real)) / x**2
     qsca = qext
 
     if m.imag != 0:
-        qsca = 2 * np.sum(cn * (abs(a)**2 + abs(b)**2)) / x2
+        qsca = 2 * np.sum(cn * (abs(a)**2 + abs(b)**2)) / x**2
 
-    qback = abs(np.sum((-1)**n * cn * (a - b)))**2 / x2
+    qback = abs(np.sum((-1)**n * cn * (a - b)))**2 / x**2
 
     c1n = n * (n + 2) / (n + 1)
     c2n = cn / n / (n + 1)
@@ -255,7 +233,7 @@ def _mie_scalar(m, x):
         asy1 = c1n[i] * (a[i] * a[i + 1].conjugate() +
                          b[i] * b[i + 1].conjugate()).real
         asy2 = c2n[i] * (a[i] * b[i].conjugate()).real
-        g += 4 * (asy1 + asy2) / qsca / x2
+        g += 4 * (asy1 + asy2) / qsca / x**2
 
     return [qext, qsca, qback, g]
 
